.transparent.svelte-1wg91mu{background:transparent}.a11y-hidden.svelte-13pq11u{display:none}.a11y-live-msg.svelte-13pq11u{position:absolute;width:1px;height:1px;margin:-1px;border:0;padding:0;overflow:hidden;clip:rect(0px,0px,0px,0px);clip-path:inset(100%)}.svelte-flow__selection.svelte-1vr3gfi{position:absolute;top:0;left:0}.svelte-flow__selection-wrapper.svelte-sf2y5e{position:absolute;top:0;left:0;z-index:2000;pointer-events:all}.svelte-flow__selection-wrapper.svelte-sf2y5e:focus,.svelte-flow__selection-wrapper.svelte-sf2y5e:focus-visible{outline:none}.svelte-flow.svelte-mkap6j{width:100%;height:100%;overflow:hidden;position:relative;z-index:0;background-color:var(--background-color, var(--background-color-default))}:root{--background-color-default: #fff;--background-pattern-color-default: #ddd;--minimap-mask-color-default: rgb(240, 240, 240, .6);--minimap-mask-stroke-color-default: none;--minimap-mask-stroke-width-default: 1;--controls-button-background-color-default: #fefefe;--controls-button-background-color-hover-default: #f4f4f4;--controls-button-color-default: inherit;--controls-button-color-hover-default: inherit;--controls-button-border-color-default: #eee}.width-resize-handle.svelte-ab9tpx{position:absolute;top:0;right:-3px;width:6px;height:100%;cursor:ew-resize;border-radius:999px}.width-resize-handle.svelte-ab9tpx:hover,.height-resize-handle.svelte-ab9tpx:hover{background:#26a69a33}.height-resize-handle.svelte-ab9tpx{position:absolute;bottom:-3px;left:0;width:100%;height:6px;cursor:ns-resize;border-radius:999px}.svelte-flow__node-group{border:none!important;background:transparent!important;box-shadow:none!important;width:auto!important;height:auto!important}.width-resize-handle.svelte-cv51mr{position:absolute;top:0;right:-3px;width:6px;height:100%;cursor:ew-resize;border-radius:999px;z-index:10;pointer-events:auto}.width-resize-handle.svelte-cv51mr:hover,.height-resize-handle.svelte-cv51mr:hover{background:#26a69a33}.height-resize-handle.svelte-cv51mr{position:absolute;bottom:-3px;left:0;width:100%;height:6px;cursor:ns-resize;border-radius:999px;z-index:10;pointer-events:auto}.resize-handle.svelte-1uha8ag{width:8px;height:100%;cursor:col-resize;background:transparent;transition:background .2s ease;pointer-events:auto;touch-action:none;flex-shrink:0;position:relative;z-index:10}.resize-handle.svelte-1uha8ag:hover,.resize-handle.active.svelte-1uha8ag{background:#94a3b8cc}
