import{am as A,N as y,M as k,Q as I,G as w,F as P,aE as C,ak as F,a as E,a0 as d,aF as O,aG as S,aH as x,h as _,e as c,aI as D,I as V,aJ as R,S as W}from"./zXDdy2c_.js";function Q(e){return e.endsWith("capture")&&e!=="gotpointercapture"&&e!=="lostpointercapture"}const B=["beforeinput","click","change","dblclick","contextmenu","focusin","focusout","input","keydown","keyup","mousedown","mousemove","mouseout","mouseover","mouseup","pointerdown","pointermove","pointerout","pointerover","pointerup","touchend","touchmove","touchstart"];function X(e){return B.includes(e)}const G={formnovalidate:"formNoValidate",ismap:"isMap",nomodule:"noModule",playsinline:"playsInline",readonly:"readOnly",defaultvalue:"defaultValue",defaultchecked:"defaultChecked",srcobject:"srcObject",novalidate:"noValidate",allowfullscreen:"allowFullscreen",disablepictureinpicture:"disablePictureInPicture",disableremoteplayback:"disableRemotePlayback"};function K(e){return e=e.toLowerCase(),G[e]??e}const j=["touchstart","touchmove"];function Y(e){return j.includes(e)}const H=new Set,U=new Set;function L(e,t,r,i={}){function n(a){if(i.capture||$.call(t,a),!a.cancelBubble)return C(()=>r?.call(this,a))}return e.startsWith("pointer")||e.startsWith("touch")||e==="wheel"?P(()=>{t.addEventListener(e,n,i)}):t.addEventListener(e,n,i),n}function Z(e,t,r,i={}){var n=L(t,e,r,i);return()=>{e.removeEventListener(t,n,i)}}function ee(e,t,r,i,n){var a={capture:i,passive:n},o=L(e,t,r,a);(t===document.body||t===window||t===document||t instanceof HTMLMediaElement)&&F(()=>{t.removeEventListener(e,o,a)})}function te(e){for(var t=0;t<e.length;t++)H.add(e[t]);for(var r of U)r(e)}let N=null;function $(e){var t=this,r=t.ownerDocument,i=e.type,n=e.composedPath?.()||[],a=n[0]||e.target;N=e;var o=0,f=N===e&&e.__root;if(f){var s=n.indexOf(f);if(s!==-1&&(t===document||t===window)){e.__root=t;return}var l=n.indexOf(t);if(l===-1)return;s<=l&&(o=s)}if(a=n[o]||e.target,a!==t){A(e,"currentTarget",{configurable:!0,get(){return a||r}});var h=I,m=w;y(null),k(null);try{for(var v,b=[];a!==null;){var g=a.assignedSlot||a.parentNode||a.host||null;try{var T=a["__"+i];T!=null&&(!a.disabled||e.target===a)&&T.call(a,e)}catch(p){v?b.push(p):v=p}if(e.cancelBubble||g===t||g===null)break;a=g}if(v){for(let p of b)queueMicrotask(()=>{throw p});throw v}}finally{e.__root=t,delete e.currentTarget,y(h),k(m)}}}function M(e){var t=document.createElement("template");return t.innerHTML=e.replaceAll("<!>","<!---->"),t.content}function u(e,t){var r=w;r.nodes_start===null&&(r.nodes_start=e,r.nodes_end=t)}function re(e,t){var r=(t&S)!==0,i=(t&x)!==0,n,a=!e.startsWith("<!>");return()=>{if(_)return u(c,null),c;n===void 0&&(n=M(a?e:"<!>"+e),r||(n=d(n)));var o=i||O?document.importNode(n,!0):n.cloneNode(!0);if(r){var f=d(o),s=o.lastChild;u(f,s)}else u(o,o);return o}}function q(e,t,r="svg"){var i=!e.startsWith("<!>"),n=(t&S)!==0,a=`<${r}>${i?e:"<!>"+e}</${r}>`,o;return()=>{if(_)return u(c,null),c;if(!o){var f=M(a),s=d(f);if(n)for(o=document.createDocumentFragment();d(s);)o.appendChild(d(s));else o=d(s)}var l=o.cloneNode(!0);if(n){var h=d(l),m=l.lastChild;u(h,m)}else u(l,l);return l}}function ae(e,t){return q(e,t,"svg")}function ne(e=""){if(!_){var t=E(e+"");return u(t,t),t}var r=c;return r.nodeType!==R&&(r.before(r=E()),W(r)),u(r,r),r}function oe(){if(_)return u(c,null),c;var e=document.createDocumentFragment(),t=document.createComment(""),r=E();return e.append(t,r),u(t,r),e}function ie(e,t){if(_){var r=w;((r.f&D)===0||r.nodes_end===null)&&(r.nodes_end=c),V();return}e!==null&&e.before(t)}const z="5";typeof window<"u"&&((window.__svelte??={}).v??=new Set).add(z);export{ie as a,H as b,u as c,oe as d,Q as e,re as f,L as g,$ as h,Y as i,te as j,X as k,M as l,ae as m,K as n,ee as o,Z as p,U as r,ne as t};
