import{f as u,a as h}from"../chunks/DDNfEvut.js";import{i as g}from"../chunks/CK3bXPEX.js";import{t as v,v as l,w as d,x,y as a,z as e,A as _}from"../chunks/zXDdy2c_.js";import{s as o}from"../chunks/QRltG_J6.js";import{s as $,p}from"../chunks/BuWykzrn.js";const k={get error(){return p.error},get status(){return p.status}};$.updated.check;const m=k;var b=u("<h1> </h1> <p> </p>",1);function j(i,f){v(f,!1),g();var t=b(),r=l(t),n=a(r,!0);e(r);var s=_(r,2),c=a(s,!0);e(s),d(()=>{o(n,m.status),o(c,m.error?.message)}),h(i,t),x()}export{j as component};
