import{d as p,a as o,f as _}from"../chunks/DDNfEvut.js";import{a as u,H as y,af as v,h as n,a0 as c,J as g,a2 as i,a4 as f,S as d,e as b,v as h,w as E}from"../chunks/zXDdy2c_.js";import{s as x,a as O,l as T}from"../chunks/C3yhlRfZ.js";function k(r,s){let t=null,l=n;var a;if(n){t=b;for(var e=c(document.head);e!==null&&(e.nodeType!==g||e.data!==r);)e=i(e);if(e===null)f(!1);else{var m=i(e);e.remove(),d(m)}}n||(a=document.head.appendChild(u()));try{y(()=>s(a),v)}finally{l&&(f(!0),d(t))}}const w=!0,C=!1,D=Object.freeze(Object.defineProperty({__proto__:null,prerender:w,ssr:C},Symbol.toStringTag,{value:"Module"}));var H=_('<link rel="icon" type="image/svg+xml"/>');function F(r,s){var t=p();k("12qhfyh",a=>{var e=H();E(()=>O(e,"href",T)),o(a,e)});var l=h(t);x(l,()=>s.children),o(r,t)}export{F as component,D as universal};
