import{f as g,u as d,g as c,i as m,j as i,k as b,l as p,n as k,o as v,q as h}from"./zXDdy2c_.js";function x(t=!1){const s=g,e=s.l.u;if(!e)return;let f=()=>k(s.s);if(t){let o=0,n={};const _=v(()=>{let l=!1;const r=s.s;for(const a in r)r[a]!==n[a]&&(n[a]=r[a],l=!0);return l&&o++,o});f=()=>p(_)}e.b.length&&d(()=>{u(s,f),i(e.b)}),c(()=>{const o=m(()=>e.m.map(b));return()=>{for(const n of o)typeof n=="function"&&n()}}),e.a.length&&c(()=>{u(s,f),i(e.a)})}function u(t,s){if(t.l.s)for(const e of t.l.s)p(e);s()}h();export{x as i};
